==> eole-ecostations_2.5.1-2.tar.gz: eole-ecostations-2/ecoStations/outils/ecoStations/arret_stations.pl <==
#! /usr/bin/perl -w
##-IEcoStations-2.0
# Académie de Besançon - PR
#
#

sub stop_ordi {
	my $ip = shift(@_);
	`/usr/share/eole/controlevnc/cliscribe.py $ip -execute 'shutdown -s -f -t 0' HIDE >/dev/null 2>&1 &`;
}

$REP_ECOSTATION="/var/www/html/outils/ecoStations";

# On lit les paramètres du fichier ecostations.txt
open(FIC_ECOSTAT, "$REP_ECOSTATION/config/ecoStations.txt") or die "ouverture impossible ecoStations.txt";
while ($ligne = <FIC_ECOSTAT>) {
        chomp($ligne);
        if ( $ligne =~ /\[(.+)\]/ ) {
                $section=$1;
		$PARAM{$section}.=" ";
        } else {
                if ( $ligne =~ /(.+)/ ) {
                        $PARAM{$section}.="$ligne ";
                }
        }
}
close(FIC_ECOSTAT);
$HR_PROG="";
	if ( $ARGV[0] =~ /H1/) {
		$HORAIRE="horaire1_exclusions";
		$INFO_HORAIRE="1";
		if ( $PARAM{horaires} =~ /^ (..:..) (..:..) $/ ){ $HR_PROG = $1; }
	} else {
		$HORAIRE="horaire2_exclusions";
		$INFO_HORAIRE="2";
		if ( $PARAM{horaires} =~ /^ (..:..) (..:..) $/ ){ $HR_PROG = $2; }
	}



$ORDI{exclus}="";
$ORDI{eteint}="";
$ORDI{inactifs}="";
open(FIC_MACHINES, "$REP_ECOSTATION/config/copie_machines.db") or die "ouverture impossible de copie_machines.db";
while ($ligne = <FIC_MACHINES>) {
	chomp($ligne);
	if ( $ligne =~ /(.+)[:|;]([0-9.]{7,15})[;|:](.+)/ ) {
		$machine=$1;
		$ip=$2;
			if ( $PARAM{$HORAIRE} =~ / $machine /i ){
				$ORDI{exclus}.="$machine, ";
			} else {
	                	if (system("tcpcheck 1 $ip:8788 | grep -q alive")>0){
					$ORDI{inactifs}.="$machine ";
			       } else {
					$ORDI{eteint}.="$machine ";
					stop_ordi($ip);
				}
			}
	}
}
close(FIC_MACHINES);

if ( ! -f "$REP_ECOSTATION/log/ecoStations.log" ) { `touch $REP_ECOSTATION/log/ecoStations.log`; }
$taille=(stat("$REP_ECOSTATION/log/ecoStations.log"))[7];
if ( $taille > 100000 ) { `mv $REP_ECOSTATION/log/ecoStations.log $REP_ECOSTATION/log/ecoStations.log.1`; }
open(FIC_LOG,">> $REP_ECOSTATION/log/ecoStations.log") or die "ouverture impossible log/ecoStations.log";
$DATE=`date '+%d/%m/%y %H:%M:%S'`;
chomp($DATE);
print FIC_LOG "--------------------------------------------------------------------------\n";
print FIC_LOG "$DATE - Arret des stations à $HR_PROG (Horaire $INFO_HORAIRE)\n";
print FIC_LOG "Ordi exclus : $PARAM{$HORAIRE}\n";
print FIC_LOG "Ordi exclus trouvés dans la base : $ORDI{exclus}\n";
print FIC_LOG "Ordi trouvés dans la base mais testés inactifs : $ORDI{inactifs}\n";
print FIC_LOG "Ordi trouvés dans la base, actifs, ayant reçu l'ordre de s'éteindre : $ORDI{eteint}\n";
print FIC_LOG "\n\n";
close(FIC_LOG);

==> eole-ecostations_2.10.0-2.tar.gz: eole-ecostations-2/ecoStations/outils/ecoStations/arret_stations.pl <==
#! /usr/bin/perl -w
##-IEcoStations-2.0
# Académie de Besançon - PR
#
#
sub stop_ordi {
	my $ip = shift(@_);
	my $name = shift(@_);
	my $version = shift(@_);
	if( $version == "2.5" || $version == "2.6" ) {
		`/usr/share/eole/controlevnc/cliscribe.py --execute 'shutdown -s -f -t 30' $ip >/dev/null 2>&1 &`;
		if ( -e '/home/netlogon/annule-ecostation.exe' ) {
			`/usr/share/eole/controlevnc/cliscribe.py --executeuser '\\\\scribe\\netlogon\\annule-ecostation.exe' $ip >/dev/null 2>&1 &`;
		}
	} else {
		`/usr/bin/salt $name system.shutdown_hard`
	}
}

$REP_ECOSTATION="/var/www/html/outils/ecoStations";

# On lit les paramètres du fichier ecostations.txt
open(FIC_ECOSTAT, "$REP_ECOSTATION/config/ecoStations.txt") or die "ouverture impossible ecoStations.txt";
while ($ligne = <FIC_ECOSTAT>) {
        chomp($ligne);
        if ( $ligne =~ /\[(.+)\]/ ) {
                $section=$1;
		$PARAM{$section}.=" ";
        } else {
                if ( $ligne =~ /(.+)/ ) {
                        $PARAM{$section}.="$ligne ";
                }
        }
}
close(FIC_ECOSTAT);
$HR_PROG="";
	if ( $ARGV[0] =~ /H1/) {
		$HORAIRE="horaire1_exclusions";
		$INFO_HORAIRE="1";
		if ( $PARAM{horaires} =~ /^ (..:..) (..:..) $/ ){ $HR_PROG = $1; }
	} else {
		$HORAIRE="horaire2_exclusions";
		$INFO_HORAIRE="2";
		if ( $PARAM{horaires} =~ /^ (..:..) (..:..) $/ ){ $HR_PROG = $2; }
	}



$ORDI{exclus}="";
$ORDI{eteint}="";
$ORDI{inactifs}="";
open(FIC_MACHINES, "$REP_ECOSTATION/config/copie_machines.db") or die "ouverture impossible machines.db";
my $version=`grep EOLE_VERSION /etc/eole/release | tr -d "'" | cut -d '=' -f2`;
while ($ligne = <FIC_MACHINES>) {
	chomp($ligne);
	if ( $ligne =~ /(.+)[:|;]([0-9.]{7,15})[;|:](.+)/ ) {
		$machine=$1;
		$ip=$2;
		if ( $PARAM{$HORAIRE} =~ / $machine /i ){
			$ORDI{exclus}.="$machine, ";
		} else {
			my $cmd;
			if( $version == "2.5" || $version == "2.6" ) {
				$cmd = system("tcpcheck 1 $ip:8788 | grep -q alive");
			} else {
				$cmd = system("salt -t 1 '$machine' test.ping |grep -q 'True'");
			}
			if ($cmd >0){
				$ORDI{inactifs}.="$machine ";
			} else {
				$ORDI{eteint}.="$machine ";
				stop_ordi($ip, $machine, $version);
			}
		}
	}
}
close(FIC_MACHINES);

if ( ! -f "$REP_ECOSTATION/log/ecoStations.log" ) { `touch $REP_ECOSTATION/log/ecoStations.log`; }
$taille=(stat("$REP_ECOSTATION/log/ecoStations.log"))[7];
if ( $taille > 100000 ) { `mv $REP_ECOSTATION/log/ecoStations.log $REP_ECOSTATION/log/ecoStations.log.1`; }
open(FIC_LOG,">> $REP_ECOSTATION/log/ecoStations.log") or die "ouverture impossible log/ecoStations.log";
$DATE=`date '+%d/%m/%y %H:%M:%S'`;
chomp($DATE);
print FIC_LOG "--------------------------------------------------------------------------\n";
print FIC_LOG "$DATE - Arret des stations à $HR_PROG (Horaire $INFO_HORAIRE)\n";
print FIC_LOG "Ordi exclus : $PARAM{$HORAIRE}\n";
print FIC_LOG "Ordi exclus trouvés dans la base : $ORDI{exclus}\n";
print FIC_LOG "Ordi trouvés dans la base mais testés inactifs : $ORDI{inactifs}\n";
print FIC_LOG "Ordi trouvés dans la base, actifs, ayant reçu l'ordre de s'éteindre : $ORDI{eteint}\n";
print FIC_LOG "\n\n";
close(FIC_LOG);
